diff src/message.c @ 9185:70d3337ff173 v7.4.1876

commit https://github.com/vim/vim/commit/a0055ad3a789b8eeb0c983d8a18d4bcaeaf456b8 Author: Bram Moolenaar <Bram@vim.org> Date: Thu Jun 2 18:37:05 2016 +0200 patch 7.4.1876 Problem: Typing "k" at the hit-enter prompt has no effect. Solution: Don't assume recursive use of the prompt if a character was typed. (Hirohito Higashi)
author Christian Brabandt <cb@256bit.org>
date Thu, 02 Jun 2016 18:45:04 +0200
parents 9200836eee15
children 32e34e574716
line wrap: on
line diff
--- a/src/message.c
+++ b/src/message.c
@@ -2475,9 +2475,9 @@ do_more_prompt(int typed_char)
     int		i;
 
     /* We get called recursively when a timer callback outputs a message. In
-     * that case don't show another prompt. Also when at the hit-Enter prompt.
-     */
-    if (entered || State == HITRETURN)
+     * that case don't show another prompt. Also when at the hit-Enter prompt
+     * and nothing was typed. */
+    if (entered || (State == HITRETURN && typed_char == 0))
 	return FALSE;
     entered = TRUE;